@@ -42,6 +42,7 @@ public:
     void setMainWindow(QWidget * parent){
     chparent=parent;
     }
+    bool on;
     int ww,//!<Window with
 	wh,//!<Window height
 	minus;//!<for streo mode swiches right and left eye view
@@ -124,7 +125,6 @@ public:
     void setupTexture();    
     void updateBondActions();
 signals:
-    void newContext();//!< this seems to be a (dirty) solution for visibility problem of the GL content
     void no_hw_st();//!< we have no hard ware stereo sorry!
     void message(const QString &);//!< small text messages to the status bar.
     void bigmessage(const QString &);//!< passes HTML strings to the info window.
@@ -153,6 +153,7 @@ public slots:
     void changeEnviRange();
     void changeTColor();
     void clearEnvi();
+    void clearLists();
     void connectSelection();
     void crosseye();
     void decFontSize();
@@ -174,11 +175,13 @@ public slots:
     void invertSelection();
     void Listen();
     void loadOrientation();
+    void loadOrientation(QString fn);
     void nostereo();
     void parallel();
     void rehide();
     void rotCenter();
     void saveOrientation();
+    void saveOrientation(QString fn);
     void selectPair(const QString &s);
     void selectResiByNr(int nr);
     void selectThisFragment();
