@@ -96,6 +96,7 @@ DSRGui::DSRGui(Molecule *mole, QString shelxlPath, Window *parent): QWidget(pare
   buttonLayout = new QVBoxLayout;
   optionboxes = new QHBoxLayout;
   fitDSRButton = new QPushButton(tr("Fit Fragment!"));
+  splitButton = new QPushButton(tr("Split Atoms"));
   fitDSRButton->setStyleSheet("QPushButton {"
                               "font-weight: bold; "
                               "color: #209920}");
@@ -104,6 +105,7 @@ DSRGui::DSRGui(Molecule *mole, QString shelxlPath, Window *parent): QWidget(pare
   editButton->setStyleSheet("QPushButton {"
                             "font-weight: bold; "
                             "color: rgb(8, 82, 182)}");
+  openLastButton = new QPushButton(tr("Restore last .res"));
   runExtBox = new QCheckBox(tr("External Restraints"));
   invertFragBox = new QCheckBox(tr("Invert Coordinates"));
   dfixBox = new QCheckBox(tr("Calculate DFIX"));
@@ -113,10 +115,11 @@ DSRGui::DSRGui(Molecule *mole, QString shelxlPath, Window *parent): QWidget(pare
   searchLabel = new QLabel(tr("Search:"));
   SearchInp = new QLineEdit;//(tr("Search a fragment here"));
   partLabel = new QLabel(tr("PART"));
-  fvarLabel = new QLabel(tr("Free Variable"));
+  fvarLabel = new QPushButton(tr("Free Variable"));  // Is a QPushbutton to have a clicked() signal
+  fvarLabel->setStyleSheet("QPushButton {border-style: outset; border-width: 0px;}");  // remove border to appear like a label
   occLabel = new QLabel(tr("Occupancy"));
   classLabel = new QLabel(tr("Residue Class"));
-  usermanualLabel = new QLabel(tr("<a href=\"http://www.xs3-data.uni-freiburg.de/data/DSR-manual.pdf\"> DSR User Manual </a>"));
+  usermanualLabel = new QLabel(tr("<a href=\"https://www.xs3-data.uni-freiburg.de/data/DSR-manual.pdf\"> DSR User Manual </a>"));
   usermanualLabel->setOpenExternalLinks(true);
   resnumbertext = new QString(tr("A residue number will be\nchosen automatically."));
   resiTextLabel = new QLabel();
@@ -222,8 +225,10 @@ DSRGui::DSRGui(Molecule *mole, QString shelxlPath, Window *parent): QWidget(pare
   buttonLayout->addWidget(fitDSRButton);
   buttonLayout->addWidget(exportFragButton);
   exportFragButton->setEnabled(false);
-  buttonLayout->addSpacing(10);
+  buttonLayout->addWidget(splitButton);
+  splitButton->setDisabled(true);
   buttonLayout->addWidget(editButton);
+  buttonLayout->addWidget(openLastButton);
   // tooltips:
   setToolTips();
   QPixmap pix = QPixmap(250, 50);
@@ -241,6 +246,7 @@ DSRGui::DSRGui(Molecule *mole, QString shelxlPath, Window *parent): QWidget(pare
   getVersionFromServer();
   // Signal slot connections:
   connect_signals_and_slots();
+  splitDecide();
   occEdit->setText("1");
   checkForDSRexecutable(splash);
   splash->finish(this);
@@ -315,6 +321,8 @@ void DSRGui::connect_signals_and_slots() {
             this, SLOT(combineOptionstext(void)));
     connect(editButton, SIGNAL(clicked(bool)),
             this, SLOT(runEditWindow()));
+    connect(openLastButton, SIGNAL(clicked(bool)),
+            this, SLOT(open_last_fileversion()));
     connect(this, SIGNAL(exportDirChanged(QString)),
             this, SLOT(exportFrag(QString)));
     // sigslot for uppdating the 3D view
@@ -338,6 +346,12 @@ void DSRGui::connect_signals_and_slots() {
             this, SLOT(setInfo(QString)));
     connect(net_manager, SIGNAL(finished(QNetworkReply*)),
             this, SLOT(isDSRUpToDate(QNetworkReply*)));
+    connect(fvarLabel, SIGNAL(clicked(bool)),
+            this, SLOT(invertFvar()));
+    connect(m_shelxle->chgl, SIGNAL(selectionChanged()),
+            this, SLOT(splitDecide(void)));
+    connect(splitButton, SIGNAL(clicked(bool)),
+            this, SLOT(splitSelectedAtoms(void)));
 }
 
 QSize DSRGui::minimumSizeHint() const {
@@ -357,7 +371,6 @@ void DSRGui::getVersionFromServer() {
     reply = net_manager->get(request);
   }
 
-
 void DSRGui::isDSRUpToDate(QNetworkReply* reply) {
   /*
    *! Displays a warning if the current DSR version is too old.
@@ -372,6 +385,9 @@ void DSRGui::isDSRUpToDate(QNetworkReply* reply) {
   if (dsrv < 193) {  // This is the first version with self-update mechanism
     updateButton->hide();
   }
+  if (dsrv < 999) {  // To be changed later (probably DSR v209)
+      splitButton->hide();
+  }
   int latestrev_int=latestRev_str.toInt(&ok,10);
   if ((ok&&ok2)&&(latestrev_int)>(dsrv)){
     info.setText(QString(
@@ -396,7 +412,6 @@ void DSRGui::isDSRUpToDate(QNetworkReply* reply) {
   disconnect(net_manager, SIGNAL(finished(QNetworkReply*)), 0, 0);
 }
 
-
 void DSRGui::updateTarget() {
   //! updates the target atoms list
   target_atoms = getSelectedAtomsList();
@@ -489,9 +504,10 @@ void DSRGui::setToolTips() {
   fitDSRButton->setToolTip("Run DSR to fit the fragment into the structure.");
   exportFragButton->setToolTip("Export the current fragment to a .res file.");
   editButton->setToolTip("Edit the current fragment or create a new one.");
+  openLastButton->setToolTip("Opens the .res file state before the last DSR fragment fit.");
 }
 
-QString DSRGui::textWrap(QString inText, int length = 75) {
+QString DSRGui::textWrap(QString inText, int length, QString subsequent_indent) {
   //! returns a SHELXL compatible wrapped string (string =\\n string) in case of over 77 characters
   //! line length
   QString firstLine = "";
@@ -504,13 +520,44 @@ QString DSRGui::textWrap(QString inText, int length = 75) {
         secondline.append(chunk+QString(" "));
       }
     }
-    return firstLine+QString("=\n")+QString("   ")+secondline;
+    return firstLine+QString("%1").arg(subsequent_indent)+secondline;
   } else {
     // nothing to wrap
     return inText;
   }
 }
 
+bool DSRGui::open_last_fileversion() {
+    //! Opens the last res file version before the last DSR action from the save history (./Shelxsaves/SAVEHIST)
+    QFileInfo fi(m_shelxle->dirName);
+    QFile currentpath(fi.absolutePath());
+    QString saveHistFileName=QString("%1/%2saves/SAVEHIST").arg(currentpath.fileName()).arg(PROGRAM_NAME);
+    QFile savehist(saveHistFileName);
+    savehist.open(QIODevice::ReadOnly|QIODevice::Text);
+    QString savehist_content = savehist.readAll();  //Entry|@|2011-03-08T13:32:19|@|b11.res|@|
+    savehist.close();
+    QRegExp re = QRegExp("Entry\\|@\\|\\w+-\\w+-\\w+:\\w+:\\w+\\|@\\|[^@]+@\\|");
+    QStringList entries = savehist_content.split(re, QString::SkipEmptyParts);
+    QFile f(m_shelxle->dirName);
+    bool success = f.open(QIODevice::WriteOnly|QIODevice::Text);
+    if (success){
+      f.write(entries.last().toLatin1().replace(0, 1, ""));
+      f.close();
+    } else {
+      return false;
+    }
+    outtext->append("Successfully restored last file version.");
+    m_shelxle->loadFile(m_shelxle->dirName);
+    return true;
+}
+
+void DSRGui::invertFvar(){
+    //! Inverts the value of FVAR in the OptionsLayout1
+    int fvar;
+    fvar = fvarspinner->text().toInt();
+    fvarspinner->setValue(-fvar);
+}
+
 void DSRGui::resetSelection() {
   //! reset the selection of source atoms
   mygl->source_atoms.clear();
@@ -529,6 +576,22 @@ void DSRGui::setInfo(QString s) {
   }
 }
 
+void DSRGui::splitDecide(void) {
+    //! Enables the "split atoms" button if at least one atom is selected.
+    if (target_atoms.count() >= 1) {
+        splitButton->setEnabled(true);
+    }
+}
+
+void DSRGui::splitSelectedAtoms(void) {
+    //! Runs DSR to split the currebtly selected atoms along the principal axis of the ellipsoid.
+    QFileInfo resfip(m_shelxle->dirName);
+    QString option = " -splt ";
+    option = option + getSelectedAtomsList();
+    option = option + " -r " + resfip.completeBaseName();
+    this->runDSR(option);
+}
+
 void DSRGui::runEditWindow(void) {
   //! Starts the edit window in order to edit a fragment
   editwindow = new DSREditWindow(m_molecule, header, dsr_db_path,
@@ -782,6 +845,7 @@ void DSRGui::activateFitButton(void) {
 void DSRGui::combineOptionstext(void) {
 //! combines all options to a single DSR command line
 //! This method gets invoked if optionTextChanged signal is emmitted
+// Idea for later: QString("%1").arg(m_shelxle->fvarCntr.value(2))
   if (!outtext->toPlainText().contains("***")) {
     outtext->clear();
   } //else {
@@ -925,13 +989,18 @@ void DSRGui::setFvarOcc(void) {
   double focc = 0;
   fvar = fvarspinner->value();
   occ = (occEdit->text().toDouble());
-  if (fvarspinner->value() < 0) {
+  if (fvar < 0) {
     focc = -(abs(fvar) * 10 + occ);
   } else {
     focc = fvar * 10 + occ;
   }
   fvarocc = QString("OCC ")+QString::number(focc);
   emit optionTextChanged();
+  outtext->append("\nFVAR num  ->  times used");
+  foreach (int fvar, m_shelxle->fvarCntr.keys()) {
+    if (fvar < 2) continue;
+    outtext->append(QString("FVAR %1  -> %2  ").arg(fvar, 3).arg(m_shelxle->fvarCntr.value(fvar), 3));
+  }
 }
 
 void DSRGui::setPART(int partnum) {
@@ -1164,6 +1233,7 @@ bool DSRGui::fitDSR() {
     option = " -target " + atoms + " " + option;
   }
   QFileInfo resfip(m_shelxle->dirName);
+  option = option + resfip.completeBaseName();
   QFileInfo check_res(resfip.completeBaseName()+".res");
   if ( resfip.completeSuffix() == "ins" && check_res.size() == 0) {
     outtext->clear();
@@ -1172,57 +1242,56 @@ bool DSRGui::fitDSR() {
                     "the .res file before you continue.");
     return false;
   }
-  QProcess dsr;
-  dsr.setProcessChannelMode(QProcess::MergedChannels);
-  dsr.closeWriteChannel();
-  dsr.setWorkingDirectory(resfip.absolutePath());
-  dsr.start(dsrpath, option.split(" ", QString::SkipEmptyParts)
-                                      << resfip.completeBaseName());
-  if (!dsr.waitForFinished())
-  {
-    dsrResulttext.append("Unable to start DSR.");
-    dsrResulttext.append(dsrpath);
-    dsrResulttext.append(dsr.readAll());
-    return false;
-  } else {
-    dsrResulttext.append(dsr.readAll());
+  bool dsr = this->runDSR(option);
+  if (!dsr) {
+      return false;
   }
-  // Display the results:
-  outtext->clear();
-  outtext->append(combiDSRline);
-  outtext->append(dsrResulttext);
   m_shelxle->loadAFile();
+  this->show();
   this->raise();
+  this->activateWindow();
   return true;
 }
 
-void DSRGui::updateDSR() {
+void DSRGui::updateDSR(void) {
   //!
   //! Updates DSR to the current version on the web server
   //!
-  QProcess dsr;
-  dsr.setProcessChannelMode(QProcess::MergedChannels);
-  dsr.closeWriteChannel();
   QString option = " -u";
-  dsr.start(dsrpath, option.split(" ", QString::SkipEmptyParts));
   outtext->append("Update running...");
-  if (!dsr.waitForFinished())
-  {
-    dsrResulttext.append("Unable to start DSR.");
-    dsrResulttext.append(dsrpath);
-    dsrResulttext.append(dsr.readAll());
-  } else {
-    dsrResulttext.append(dsr.readAll());
-  }
-  // Display the results:
-  outtext->clear();
-  outtext->append(dsrResulttext);
+  this->runDSR(option);
+}
+
+bool DSRGui::runDSR(QString option) {
+    QFileInfo resfip(m_shelxle->dirName);
+    QProcess dsr;
+    dsr.setProcessChannelMode(QProcess::MergedChannels);
+    dsr.closeWriteChannel();
+    dsr.setWorkingDirectory(resfip.absolutePath());
+    dsr.start(dsrpath, option.split(" ", QString::SkipEmptyParts));
+    if (!dsr.waitForFinished())
+    {
+      dsrResulttext.append("Unable to start DSR.");
+      dsrResulttext.append(dsrpath);
+      dsrResulttext.append(dsr.readAll());
+      return false;
+    } else {
+      dsrResulttext.append(dsr.readAll());
+    }
+    // Display the results:
+    outtext->clear();
+    outtext->append(combiDSRline);
+    outtext->append(dsrResulttext);
+    this->show();
+    this->raise();
+    this->activateWindow();
+    return true;
 }
 
 void DSRGui::searchFragment(QString searchName) {
   //! Searches for fragments in the database
   QString *result = new QString;
-  if ((searchName.length() < 3) && (searchName.length() > 0)){
+  if ((searchName.length() < 2) && (searchName.length() > 0)){
     return;
   }
   // If search length is zero, restore full list:
@@ -1245,8 +1314,17 @@ void DSRGui::searchFragment(QString searchName) {
   } else {
     result->append(dsr.readAll());
   }
-  QStringList list = result->split(QRegExp("\n|\r\n|\r"));
-  displayFragmentsList(list, "None");
+  QVector<QStringList> fraglist;
+  fraglist.clear();
+  foreach (QString line, result->split(QRegExp("\n|\r\n|\r"))) {
+    if (line.isEmpty()){
+      continue;
+    }
+    if (line.contains(";;")) {
+      fraglist.append(line.split(";;"));
+    }
+  }
+  displayFragmentsList(fraglist, "None");
 }
 
 bool DSRGui::isDSRVersionCorrect(QString version) {
@@ -1282,12 +1360,12 @@ bool DSRGui::listDSRdbFragments(QString fav="None") {
   } else {
     fraglist->append(dsr.readAll());
   }
-  QStringList list = fraglist->split(QRegExp("\n|\r\n|\r"));
-  if (list.last().isEmpty())
-    list.removeLast();
+  QStringList string_list = fraglist->split(QRegExp("\n|\r\n|\r"));
+  if (string_list.last().isEmpty())
+    string_list.removeLast();
   bool versionOk;
   versionOk = false;
-  foreach (QString line, list) {
+  foreach (QString line, string_list) {
     if (line.contains("Duplicate database entry")) {
       outtext->clear();
       outtext->append(*fraglist);
@@ -1297,27 +1375,28 @@ bool DSRGui::listDSRdbFragments(QString fav="None") {
   // in this case no fragment list returned. Hence, we have an error.
   if (!fraglist->contains(";;")) {
     outtext->clear();
-    outtext->append(*fraglist);
-    outtext->append(dsr.errorString());
+    outtext->append("Something went wrong with DSR. please tell Daniel Kratzert (dkratzert@gmx.de) about this problem.");
     return false;
   }
-  foreach (QString line, list) {
+  foreach (QString line, string_list) {
     if (line.isEmpty()){
-      list.removeFirst();
+      continue;
     }
-    if ( (line.split(":").size() >= 1)
-         && line.contains("DSR version:")) {
+    if ( (line.split(":").size() >= 1) && line.contains("DSR version:")) {
       dsrVersion = line.split(":").at(1).trimmed();
     }
-  }
-  if (list[0].trimmed().contains("DSR version:")) {
-    versionOk = isDSRVersionCorrect(dsrVersion);
-    list.removeFirst();
-  } else {
-    outtext->clear();
-    outtext->append(*fraglist);
-    outtext->append("Something went wrong with DSR. Please report this to Daniel Kratzert.");
-    return false;
+    if (line.trimmed().contains("DSR version:")) {
+      versionOk = isDSRVersionCorrect(dsrVersion);
+      continue;
+    }
+    if (line.trimmed().startsWith("***")) {
+      outtext->append(line);
+      continue;
+    }
+    if (line.contains(";;")) {
+      // collect frags to global list here:
+      fragmentsList->append(line.split(";;")); // the global list of all fragments
+    }
   }
   if (!versionOk) {
     outtext->clear();
@@ -1325,39 +1404,23 @@ bool DSRGui::listDSRdbFragments(QString fav="None") {
     outtext->append(QString(tr("Please get the most recent version from https://www.xs3.uni-freiburg.de/research/dsr")));
     return false;
   }
-  displayFragmentsList(list, fav);
-  QStringList line;
-  for (int i = 0; i < list.size(); ++i) {
-    line.clear();
-    if (!list[i].contains(";;")){
-      continue;
-    }
-    line = list[i].split(";;");
-    if ( line.size() < 3 ) {
-      continue;
-    }
-    fragmentsList->append(line); // the global list of all fragments
-  }
+  displayFragmentsList(*fragmentsList, fav);
   return true;
 }
 
 
-void DSRGui::displayFragmentsList(QStringList list, QString fav="None") {
+void DSRGui::displayFragmentsList(QVector<QStringList> list, QString fav="None") {
   //! displays the list of fragments in a table view
   //! The first column (the tag) is hidden, only the name is displayed.
   QStandardItem *fraglabel = new QStandardItem(QString("Fragment Name"));
   fraglabel->setTextAlignment(Qt::AlignLeft);
-  QStandardItemModel *FragListmodel = new QStandardItemModel(
-                                list.size()-1, 2, this); //x Rows and 2 Columns
+  QStandardItemModel *FragListmodel = new QStandardItemModel(list.size(), 2, this); //x Rows and 2 Columns
   FragListmodel->setHorizontalHeaderItem(0, new QStandardItem(QString("tag")));
   FragListmodel->setHorizontalHeaderItem(1, fraglabel);
   QStringList line;
   for (int i = 0; i < list.size(); ++i) {
     line.clear();
-    if (!list[i].contains(";;")){
-      continue;
-    }
-    line = list[i].split(";;");
+    line = list[i];
     if ( line.size() < 3 ) {
       continue;
     }
