@@ -478,8 +478,8 @@ QString XLOutputParser::residualsTextDisplay(QString &line, int ls_cycles) {
   if (!listf_data.R1_4sig.isEmpty() && !listf_data.finalwR2.isEmpty()) { // final values:
     html_final = QString("<tr><td align=right><b><i>wR</i><sub>2</sub> = </b></td> <td><b> %2% </b>(all data) </td>"
                          "    <td align=right><b><i>R</i><sub>1</sub></b> [<i>I</i> > 4&sigma;<i>I</i>] = </td> <td><b>%1%</b> (%9% all data)</td></tr>"
-                         "<tr><td align=right>Highest peak = </td> <td> %3 e&#8491;<sup>-3</sup> at %4 &#8491; from %7 &nbsp;&nbsp;&nbsp;&nbsp;</td>"
-                         "    <td align=right>Deepest hole = </td> <td> %5 e&#8491;<sup>-3</sup> at %6 &#8491; from %8 </td></tr>"
+                         "<tr><td align=right>Highest peak = </td> <td> %3 e&Aring;<sup>-3</sup> at %4 &Aring; from %7 &nbsp;&nbsp;&nbsp;&nbsp;</td>"
+                         "    <td align=right>Deepest hole = </td> <td> %5 e&Aring;<sup>-3</sup> at %6 &Aring; from %8 </td></tr>"
                          )
           .arg(listf_data.R1_4sig.toDouble()*100, 4, 'f', 2, 0)      // 1
           .arg(listf_data.finalwR2.toDouble()*100, 4, 'f', 2, 0)     // 2
@@ -556,7 +556,7 @@ QString XLOutputParser::residualsTextDisplay(QString &line, int ls_cycles) {
           "%3"
           "<tr><td align=right> <i>GooF</i> =             </td> <td> %4                     </td>"
           "    <td align=right  width=18%> Restr. <i>GooF</i> =  </td> <td> %5              </td></tr>"
-          "<tr><td align=right> Max. shift =              </td> <td %6> %7 &#8491; - %8     </td>"
+          "<tr><td align=right> Max. shift =              </td> <td %6> %7 &Aring; - %8     </td>"
           "    <td align=right> Max. &Delta;U =           </td> <td %21> %9 - %10          </td></tr>"
           "</table>"
           "<table><tr><td bgcolor=#ffec99><b> %11 </b></td></tr></table>"
