@@ -22,9 +22,9 @@
 #ifndef fmin
 #define fmin(x, y) (((x) < (y)) ? (x) : (y))
 #endif
-#ifndef round
-#define round(x) (x<0?ceil((x)-0.5):floor((x)+0.5))
-#endif
+//#ifndef round 
+//#define round(x) (x<0)?ceil((x)-0.5):floor((x)+0.5)
+//#endif
 #include <QString>
 #include <QStringList>
 #include <QList>
@@ -251,6 +251,7 @@ typedef struct MyAtom{
   QString orginalLine;
   //! fragment number of the structure part
   int molindex;
+  //! Binary flag for fixed (tied to first FVAR) atom parameters.
   int fixFlag;
   //! the symmetry number  
   int symmGroup ;
