@@ -410,6 +410,11 @@ QString myfcf(QString fn){
 
   //  printf("wave:%f %f %f %f %d %d wl=%d\n",mol->cell.wave,fabs(mol->cell.wave-0.71073),fabs(mol->cell.wave-1.5418),fabs(mol->cell.wave-0.56083), mol->cell.ns0, mol->cell.symmops.size(),wl);
 
+  printf("hklf N=%d s:%g \n%g %g %g\n%g %g %g\n%g %g %g\nsm: %g \n",mol->hklf,mol->hklScale ,
+      mol->hklMat.m11,mol->hklMat.m12,mol->hklMat.m13,
+      mol->hklMat.m21,mol->hklMat.m22,mol->hklMat.m23,
+      mol->hklMat.m31,mol->hklMat.m32,mol->hklMat.m33,
+      mol->hklSigmaScale);
   QTime zeit; zeit.start();
   while (!feof(hkl)){    
     fgets(line,120,hkl);
@@ -595,7 +600,7 @@ loop_\n_refln_index_h\n_refln_index_k\n_refln_index_l\n_refln_F_squared_meas\n_r
     // ,lr[i].dis
     );// */
 
-    float iosig = pow(lr[i].fo/myosf,2.0)/(lr[i].si/(osf2));
+    float iosig = powf(lr[i].fo/myosf,2.0f)/(lr[i].si/(osf2));
     if ((lr[i].fc>0.001)&& (iosig>-1.0)){
       igut++;
       sfo+=lr[i].fo/myosf;
@@ -607,7 +612,7 @@ loop_\n_refln_index_h\n_refln_index_k\n_refln_index_l\n_refln_F_squared_meas\n_r
           ,lr[i].ik
           ,lr[i].il
           //        ,(pow(lr[i].fo/mol->osf,2.0))/(1.0+lr[i].dis)
-          ,pow(lr[i].fo/myosf,2.0)
+          ,powf(lr[i].fo/myosf,2.0f)
           ,lr[i].si/(osf2)
           //,sqrt(lr[i].dis)
           ,lr[i].fc
