@@ -49,6 +49,7 @@
 #include "calculator.h"
 #include "dsrgui.h"
 #include "listfile.h"
+#define SX_LINE_LENGTH 80
 
 /*! \brief Window is the main window class of ShelXle most of the magic happens here ;-)
 *
@@ -92,7 +93,7 @@ public:
   QList<double> fvar;//!<List of Free Variables.
   QMap<int,int> fvarCntr;//!<Free Variable counter QMap.
   bool isLabelInUse();//!< Checks if the current Label in the reaname dialog is in use. \returns true if Label is already in use.
-  QString dirName;
+  QString dirName; //!< Full path of the currently opened file (including file name).
   void setFocus(bool b){focusSet=b;}
   bool isFocusSet() {return focusSet;}
   int firstAtomLine;
@@ -112,11 +113,13 @@ public slots:
   void changeIconSize();//!<Changes the size of the tool bar icons.
   void changeIndexofLabel(const int i);//!<NextLabel of rename mode consists of labelPSE labelIndex labelSuffix, this changes the LabelIndex to pse. @param i next labelIndex. For i < 0 no number in label. 
   void changeLabelFont();//!<Changes the font of the on screen Labels of the atoms.
+  void changeResiPart();//!< change the resi or part of selected atoms.
   void changeScalefactor();//!<Changes the screen shot scale factor. 
   void changeSortierWeise(QAction* action);//!<Changes the sorting option to action->data. @param action the calling QAction.
   void changeSuffixofLabel(const QString &fix);//!<NextLabel of rename mode consists of labelPSE labelIndex labelSuffix, this changes the labelSuffix @param fix next labelSuffix.
   void checkForUpdates();//!<Checks via the internet if new versions of ShelXle are availabe.
   void clipboardDataChanged();//!<Enables the paste action if something is in the clipboard.
+  void clearStructure();
   void closeEvent(QCloseEvent *event);//!<Tidys everything up and stores settings befor closing the ShelXle app.
   void colorDLGFOP();//!<Color Dialog for Fobs plus. Positive values of Fo map are drawn with a mesh in this color.
   void colorDLGFOM();//!<Color Dialog for Fobs minus. Negative values of Fo map are drawn with a mesh in this color.
@@ -212,6 +215,7 @@ public slots:
   void renameRNchanged(int ii);//!< Residue Number of rename mode is changed to ii @param ii residue number.
   void renameThisAtom();//!< The label of the specified atom is used to feed the inputs of rename mode and the latter is opened.  
   void renameThisAtom(int index);//!< specified atom is renamed as given by rename mode
+  void rename2ThisAtom(int index);//!< tries to find an apropriate H label
   void renamUpdate(bool vis);//!<rename mode gets shown or hidden. @param vis visibitity of rename mode.
   void replaceAll();//!<replace all functionality of search and replace in the editor.
   void replaceNext();//!<replace next functionality of search and replace in the editor.
@@ -252,7 +256,6 @@ public slots:
   void toggDocWid(bool weg);//!< hides Text Windows
   void toggleEQHighlighting(bool);//!< toggles higlighting of symmetry generated atoms.
   void toggleOrtho(bool ov);//!< toggles orthographic and perspective projection.
-  void trick();//!< a (dirty) trick to show the GLWidget in the right way all the time. 
   void undoRename();//!<if undo is clicked and it was a rename a rename is undone.
   void uniq();//!< moves centers of gravity of all molecules into the unit cell box. !does not heal scrambled molecules!
   void unique();//!< !does ?not? heal scrambled molecules!
@@ -300,6 +303,7 @@ private:
   int ls_cycls;   //!< Number of least-squares cycles during L.S. or CGLS refinement.
   int SDM_Limit; //!< if the number of atoms in the au exceeds this limit shortest distance is not computed automatically default 350
   double defden(V3 pos,CEnvironment belo);
+  bool nowaste;// start labeling always at 1
   QNetworkAccessManager *net;
   QNetworkReply *reply;
   V3 urs;
@@ -341,6 +345,7 @@ private:
   QLabel *tieFVNrL;
   QSpinBox *tieFVNr;
   QLabel *tieUsedL;
+  QDoubleSpinBox *tieFix;
   QString FFTErrorString;
   QComboBox *sufixBox;
   QLineEdit *resiResiClass;
@@ -376,7 +381,7 @@ private:
   QString unitAlt, unitNeu, shelxlPath, shelxlArgs;
   bool useMyBArray;    //! If set to true, the b-array is not automatically set by ShelXle
   QStringList extraProgramNames,extraProgramPaths,extraOptions,extraExt2;
-  QList<Qt::CheckState>  extraArguments,extraExtensions, extraDetach;
+  QList<Qt::CheckState>  extraArguments,extraExtensions, extraDetach, extraResIns;
   QLineEdit *extraPath,*extraName,*extraAltExtEdit,*extraArgumentsEdit,*shxPath,*shxOptions;
   QDockWidget *helpDock;
 //  QWebView *hilfe;
@@ -396,12 +401,12 @@ private:
   QAction *backColor,*labelColor;
   QVBoxLayout *lt;
   QToolButton  *zoomIn,*zoomOut;
-  QLabel *sLabel;
+  QLabel *sLabel, *fvused;
   QCheckBox *qGrowPeak,*search4duplicates;
   QTimer *hidwillpse;
   QLabel *indexL,*sufixL;
   QLabel *scalwla, *scalhla, *scalsla, *header;
-  QDialogButtonBox *buttonBoxMC; 
+  QDialogButtonBox *buttonBoxMC,*buttonBoxRN; 
   QPushButton *applyMC;          
   QPushButton *applyDF;          
   QLabel *wl, *pl, *dl, *ol, *rl, *sl, *lw, *ltz;
@@ -424,6 +429,7 @@ private:
   QCheckBox *useArgument;
   QCheckBox *omitExtension;
   QCheckBox *detach;
+  QCheckBox *copyResIns; 
   QSize ediSize;
   QPoint ediPos;
   QComboBox *resiFinder;
@@ -442,6 +448,7 @@ private:
 	  *ballStyle,
       *separateLabelFile,
       *toggleOrthoView,
+      *belocube,
       *actionUniq,
       *actionSearch,
       *actionNext,
